@@ -1771,14 +1771,24 @@ _store_settings(ScoutWindow* self)
   g_object_unref(client);
 }
 
+static void
+_enable_start_search(ScoutWindow* self)
+{
+  if(!self->priv->search_active)
+  {
+    g_warning("enable search\n");
+    g_free(self->priv->current_search_text);
+    self->priv->current_search_text = NULL;
+  }
+}
+
 static void
 toggle_contact_search_option(GtkToggleButton* button, gpointer user_data)
 {
   g_return_if_fail(IS_SCOUT_WINDOW(user_data));
   ScoutWindow* self = SCOUT_WINDOW(user_data);
   self->priv->search_in_contacts = gtk_toggle_button_get_active(button);
-  g_free(self->priv->current_search_text);
-  self->priv->current_search_text = NULL;
+  _enable_start_search(self);
 }
 
 static void
@@ -1787,8 +1797,7 @@ toggle_conversation_search_option(GtkToggleButton* button, gpointer user_data)
   g_return_if_fail(IS_SCOUT_WINDOW(user_data));
   ScoutWindow* self = SCOUT_WINDOW(user_data);
   self->priv->search_in_conversations = gtk_toggle_button_get_active(button);
-  g_free(self->priv->current_search_text);
-  self->priv->current_search_text = NULL;
+  _enable_start_search(self);
 }
 
 static void
@@ -1797,8 +1806,7 @@ toggle_calendar_search_option(GtkToggleButton* button, gpointer user_data)
   g_return_if_fail(IS_SCOUT_WINDOW(user_data));
   ScoutWindow* self = SCOUT_WINDOW(user_data);
   self->priv->search_in_calendars = gtk_toggle_button_get_active(button);
-  g_free(self->priv->current_search_text);
-  self->priv->current_search_text = NULL;
+  _enable_start_search(self);
 }
 
 static void
@@ -1807,8 +1815,7 @@ toggle_case_sensitive_search_option(GtkToggleButton* button, gpointer user_data)
   g_return_if_fail(IS_SCOUT_WINDOW(user_data));
   ScoutWindow* self = SCOUT_WINDOW(user_data);
   self->priv->search_case_sensitive = gtk_toggle_button_get_active(button);
-  g_free(self->priv->current_search_text);
-  self->priv->current_search_text = NULL;
+  _enable_start_search(self);
 }
 
 static void
@@ -1870,6 +1877,12 @@ _show_settings_dialog_cb(GtkButton* button, gpointer data)
   gtk_widget_destroy(dialog);
 }
 
+static void
+_re_enable_search_start(GtkWidget* widget, gpointer user_data)
+{
+  _enable_start_search(SCOUT_WINDOW(user_data));
+}
+
 static void
 _init_menu(ScoutWindow* self)
 {
@@ -1908,8 +1921,7 @@ _init_menu(ScoutWindow* self)
   hildon_app_menu_append(menu, GTK_BUTTON(show_calendar_search_settings));
   hildon_app_menu_append(menu, GTK_BUTTON(show_conversations_search_settings));
   hildon_app_menu_append(menu, GTK_BUTTON(case_sensitive_search));
-
-
+  g_signal_connect(menu, "hide", G_CALLBACK(_re_enable_search_start), self);
   gtk_widget_show_all(GTK_WIDGET(menu));
   hildon_window_set_app_menu(HILDON_WINDOW(self), menu);
 }
